# Generated by Django 2.0.2 on 2019-02-22 16:01

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('jobs', '0002_job_job_id'),
    ]

    operations = [
        migrations.AlterField(
            model_name='job',
            name='container',
            field=models.CharField(blank=True, max_length=256),
        ),
        migrations.AlterField(
            model_name='job',
            name='log',
            field=models.TextField(blank=True),
        ),
        migrations.AlterField(
            model_name='job',
            name='tag',
            field=models.CharField(blank=True, max_length=256),
        ),
    ]
