# Generated by Django 2.0.2 on 2019-02-22 15:54

from django.db import migrations, models


class Migration(migrations.Migration):

    initial = True

    dependencies = [
    ]

    operations = [
        migrations.CreateModel(
            name='Job',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('driver', models.CharField(max_length=256)),
                ('site', models.CharField(max_length=256)),
                ('status', models.CharField(max_length=256)),
                ('tag', models.CharField(max_length=256)),
                ('container', models.CharField(max_length=256)),
                ('log', models.TextField()),
            ],
        ),
    ]
