# Generated by Django 2.0.2 on 2019-02-22 16:02

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('jobs', '0003_auto_20190222_1601'),
    ]

    operations = [
        migrations.AlterField(
            model_name='job',
            name='status',
            field=models.CharField(blank=True, max_length=256),
        ),
    ]
